==> kdegames-1.91.tar.bz2: kdegames-1.91/kpat/mod3.h <==
/*---------------------------------------------------------------------------

  mod3.cpp  implements a patience card game

     Copyright (C) 1997  Rodolfo Borges

 * Permission to use, copy, modify, and distribute this software and its
 * documentation for any purpose and without fee is hereby granted,
 * provided that the above copyright notice appear in all copies and that
 * both that copyright notice and this permission notice appear in
 * supporting documentation.
 *
 * This file is provided AS IS with no warranties of any kind.  The author
 * shall have no liability with respect to the infringement of copyrights,
 * trade secrets or any patents by this file or any part thereof.  In no
 * event will the author be liable for any lost revenue or profits or
 * other special, indirect and consequential damages.

 (I don't know a name for this one, if you do, please tell me.)

---------------------------------------------------------------------------*/

#ifndef _MOD3_H_
#define _MOD3_H_

#include "patience.h"

class Mod3 : public dealer
{
	Q_OBJECT

public:
	Mod3( QWidget* parent=0, const char* name=0);
	virtual ~Mod3();

	virtual void show();
	virtual void undo();

	QSize sizeHint() const;

public slots:
	void redeal();
	void deal();
	virtual void restart();

private: // functions
	static bool CanPut (const Card* c1, const Card* c2);

private:
	cardPos* stack[4][8];
	Deck *deck;
	QPushButton rb;
};

#endif

//-------------------------------------------------------------------------//

==> kdegames-2.1.1.tar.bz2: kdegames-2.1.1/kpat/mod3.h <==
/*---------------------------------------------------------------------------

  mod3.cpp  implements a patience card game

     Copyright (C) 1997  Rodolfo Borges

 * Permission to use, copy, modify, and distribute this software and its
 * documentation for any purpose and without fee is hereby granted,
 * provided that the above copyright notice appear in all copies and that
 * both that copyright notice and this permission notice appear in
 * supporting documentation.
 *
 * This file is provided AS IS with no warranties of any kind.  The author
 * shall have no liability with respect to the infringement of copyrights,
 * trade secrets or any patents by this file or any part thereof.  In no
 * event will the author be liable for any lost revenue or profits or
 * other special, indirect and consequential damages.

 (I don't know a name for this one, if you do, please tell me.)

---------------------------------------------------------------------------*/

#ifndef _MOD3_H_
#define _MOD3_H_

#include "dealer.h"

class Mod3 : public Dealer
{
    Q_OBJECT

public:
    Mod3( KMainWindow* parent=0, const char* name=0);
    void deal();
    virtual void restart();

public slots:
    void deckClicked(Card *c);

protected:
    virtual bool startAutoDrop() { return false; }
    virtual Card *demoNewCards();

private: // functions
    virtual bool checkAdd( int checkIndex, const Pile *c1, const CardList& c2) const;
    void dealRow(int row);

private:
    Pile* stack[4][8];
    Pile* aces;
    Deck* deck;
};

#endif

//-------------------------------------------------------------------------//
